@@ -6,31 +6,42 @@
 # -----------------------------------------------------------------------------
 """an interactive shell for the netaddr library"""
 
-import os
+import argparse
 import sys
 import netaddr
-from netaddr import *
 
-#   aliases to save some typing ...
-from netaddr import IPAddress as IP, IPNetwork as CIDR
-from netaddr import EUI as MAC
+SHELL_NAMESPACE = {
+    **{name: getattr(netaddr, name) for name in dir(netaddr) if name in netaddr.__all__},
+    #   aliases to save some typing ...
+    'IP': netaddr.IPAddress,
+    'CIDR': netaddr.IPNetwork,
+    'MAC': netaddr.EUI,
+}
 
-
-def main():
-    banner = r"""               __            __    __
+ASCII_ART_LOGO = r"""               __            __    __
    ____  ___  / /_____ _____/ /___/ /____
   / __ \/ _ \/ __/ __ `/ __  / __  / ___/
  / / / /  __/ /_/ /_/ / /_/ / /_/ / /
 /_/ /_/\___/\__/\__,_/\__,_/\__,_/_/
+"""
 
-netaddr shell %s - %s
+
+def main():
+    print(ASCII_ART_LOGO)
+
+    parser = argparse.ArgumentParser(
+        prog='netaddr', description='The netaddr CLI tool', epilog='Share and enjoy!'
+    )
+    _args = parser.parse_args()
+
+    banner = r"""netaddr shell %s - %s
 """ % (netaddr.__version__, __doc__)
     exit_msg = '\nShare and enjoy!'
 
     try:
         from IPython.terminal.embed import InteractiveShellEmbed
 
-        ipshell = InteractiveShellEmbed(banner1=banner, exit_msg=exit_msg, user_ns=globals())
+        ipshell = InteractiveShellEmbed(banner1=banner, exit_msg=exit_msg, user_ns=SHELL_NAMESPACE)
     except ImportError:
         sys.stderr.write('IPython (http://ipython.scipy.org/) not found!\n')
         sys.exit(1)
