@@ -1,24 +1,23 @@
-#-----------------------------------------------------------------------------
-#   Copyright (c) 2008-2015, David P. D. Moss. All rights reserved.
+# -----------------------------------------------------------------------------
+#   Copyright (c) 2008 by David P. D. Moss. All rights reserved.
 #
 #   Released under the BSD license. See the LICENSE file for details.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 """Fallback routines for Python's standard library socket module"""
 
 from struct import unpack as _unpack, pack as _pack
 
-from netaddr.compat import _bytes_join, _is_str
 
-AF_INET   =  2
-AF_INET6  = 10
+AF_INET = 2
+AF_INET6 = 10
 
 
 def inet_ntoa(packed_ip):
     """
     Convert an IP address from 32-bit packed binary format to string format.
     """
-    if not _is_str(packed_ip):
-        raise TypeError('string type expected, not %s' % str(type(packed_ip)))
+    if not isinstance(packed_ip, str):
+        raise TypeError('string type expected, not %s' % type(packed_ip))
 
     if len(packed_ip) != 4:
         raise ValueError('invalid length of packed IP address string')
@@ -61,8 +60,7 @@ def _compact_ipv6_tokens(tokens):
                 best_position = position
         #   Replace chosen zero run.
         (length, start_idx) = best_position
-        new_tokens = new_tokens[0:start_idx] + [''] + \
-                     new_tokens[start_idx+length:]
+        new_tokens = new_tokens[0:start_idx] + [''] + new_tokens[start_idx + length :]
 
         #   Add start and end blanks so join creates '::'.
         if new_tokens[0] == '':
@@ -81,7 +79,7 @@ def inet_ntop(af, packed_ip):
         return inet_ntoa(packed_ip)
     elif af == AF_INET6:
         #   IPv6.
-        if len(packed_ip) != 16 or not _is_str(packed_ip):
+        if len(packed_ip) != 16 or not isinstance(packed_ip, bytes):
             raise ValueError('invalid length of packed IP address string')
 
         tokens = ['%x' % i for i in _unpack('>8H', packed_ip)]
@@ -94,7 +92,7 @@ def inet_ntop(af, packed_ip):
             word = word << 16 * i
             int_val = int_val | word
 
-        if 0xffff < int_val <= 0xffffffff or int_val >> 32 == 0xffff:
+        if 0xFFFF < int_val <= 0xFFFFFFFF or int_val >> 32 == 0xFFFF:
             #   IPv4 compatible / mapped IPv6.
             packed_ipv4 = _pack('>2H', *[int(i, 16) for i in tokens[-2:]])
             ipv4_str = inet_ntoa(packed_ipv4)
@@ -112,8 +110,8 @@ def _inet_pton_af_inet(ip_string):
     by only support decimal octets. Using octal or hexadecimal values will
     raise a ValueError exception.
     """
-    #TODO: optimise this ... use inet_aton with mods if available ...
-    if _is_str(ip_string):
+    # TODO: optimise this ... use inet_aton with mods if available ...
+    if isinstance(ip_string, str):
         invalid_addr = ValueError('illegal IP address string %r' % ip_string)
         #   Support for hexadecimal and octal octets.
         tokens = ip_string.split('.')
@@ -122,8 +120,7 @@ def _inet_pton_af_inet(ip_string):
         if len(tokens) == 4:
             words = []
             for token in tokens:
-                if token.startswith('0x') or \
-                  (token.startswith('0') and len(token) > 1):
+                if token.startswith('0x') or (token.startswith('0') and len(token) > 1):
                     raise invalid_addr
                 try:
                     octet = int(token)
@@ -133,7 +130,7 @@ def _inet_pton_af_inet(ip_string):
                 if (octet >> 8) != 0:
                     raise invalid_addr
                 words.append(_pack('B', octet))
-            return _bytes_join(words)
+            return b''.join(words)
         else:
             raise invalid_addr
 
@@ -153,7 +150,7 @@ def inet_pton(af, ip_string):
         #   IPv6.
         values = []
 
-        if not _is_str(ip_string):
+        if not isinstance(ip_string, str):
             raise invalid_addr
 
         if 'x' in ip_string:
@@ -190,15 +187,17 @@ def inet_pton(af, ip_string):
             if not 0 <= token_count <= 8 - 1:
                 raise invalid_addr
 
-            gap_size = 8 - ( len(l_prefix) + len(l_suffix) )
+            gap_size = 8 - (len(l_prefix) + len(l_suffix))
 
-            values = [_pack('>H', int(i, 16)) for i in l_prefix] \
-                   + ['\x00\x00'.encode() for i in range(gap_size)] \
-                   + [_pack('>H', int(i, 16)) for i in l_suffix]
+            values = (
+                [_pack('>H', int(i, 16)) for i in l_prefix]
+                + ['\x00\x00'.encode() for i in range(gap_size)]
+                + [_pack('>H', int(i, 16)) for i in l_suffix]
+            )
             try:
                 for token in l_prefix + l_suffix:
                     word = int(token, 16)
-                    if not 0 <= word <= 0xffff:
+                    if not 0 <= word <= 0xFFFF:
                         raise invalid_addr
             except ValueError:
                 raise invalid_addr
@@ -231,7 +230,7 @@ def inet_pton(af, ip_string):
                 try:
                     tokens = [int(token, 16) for token in tokens]
                     for token in tokens:
-                        if not 0 <= token <= 0xffff:
+                        if not 0 <= token <= 0xFFFF:
                             raise invalid_addr
 
                 except ValueError:
@@ -241,6 +240,6 @@ def inet_pton(af, ip_string):
             else:
                 raise invalid_addr
 
-        return _bytes_join(values)
+        return b''.join(values)
     else:
         raise ValueError('Unknown address family %d' % af)
